==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/MongoClusterFirewallRule.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin

import com.pulumi.azurenative.documentdb.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.documentdb.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [MongoClusterFirewallRule].
 */
@PulumiTagMarker
public class MongoClusterFirewallRuleResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: MongoClusterFirewallRuleArgs = MongoClusterFirewallRuleArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend MongoClusterFirewallRuleArgsBuilder.() -> Unit) {
        val builder = MongoClusterFirewallRuleArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): MongoClusterFirewallRule {
        val builtJavaResource =
            com.pulumi.azurenative.documentdb.MongoClusterFirewallRule(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return MongoClusterFirewallRule(builtJavaResource)
    }
}

/**
 * Represents a mongo cluster firewall rule.
 * Azure REST API version: 2023-03-15-preview.
 * Other available API versions: 2023-09-15-preview, 2023-11-15-preview, 2024-02-15-preview.
 * ## Example Usage
 * ### Create a firewall rule of the mongo cluster
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var mongoClusterFirewallRule = new AzureNative.DocumentDB.MongoClusterFirewallRule("mongoClusterFirewallRule", new()
 *     {
 *         EndIpAddress = "255.255.255.255",
 *         FirewallRuleName = "rule1",
 *         MongoClusterName = "myMongoCluster",
 *         ResourceGroupName = "TestGroup",
 *         StartIpAddress = "0.0.0.0",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/documentdb/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := documentdb.NewMongoClusterFirewallRule(ctx, "mongoClusterFirewallRule", &documentdb.MongoClusterFirewallRuleArgs{
 * 			EndIpAddress:      pulumi.String("255.255.255.255"),
 * 			FirewallRuleName:  pulumi.String("rule1"),
 * 			MongoClusterName:  pulumi.String("myMongoCluster"),
 * 			ResourceGroupName: pulumi.String("TestGroup"),
 * 			StartIpAddress:    pulumi.String("0.0.0.0"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.documentdb.MongoClusterFirewallRule;
 * import com.pulumi.azurenative.documentdb.MongoClusterFirewallRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var mongoClusterFirewallRule = new MongoClusterFirewallRule("mongoClusterFirewallRule", MongoClusterFirewallRuleArgs.builder()
 *             .endIpAddress("255.255.255.255")
 *             .firewallRuleName("rule1")
 *             .mongoClusterName("myMongoCluster")
 *             .resourceGroupName("TestGroup")
 *             .startIpAddress("0.0.0.0")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:documentdb:MongoClusterFirewallRule rule1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DocumentDB/mongoClusters/{mongoClusterName}/firewallRules/{firewallRuleName}
 * ```
 */
public class MongoClusterFirewallRule internal constructor(
    override val javaResource: com.pulumi.azurenative.documentdb.MongoClusterFirewallRule,
) : KotlinCustomResource(javaResource, MongoClusterFirewallRuleMapper) {
    /**
     * The end IP address of the mongo cluster firewall rule. Must be IPv4 format.
     */
    public val endIpAddress: Output<String>
        get() = javaResource.endIpAddress().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The provisioning state of the firewall rule.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * The start IP address of the mongo cluster firewall rule. Must be IPv4 format.
     */
    public val startIpAddress: Output<String>
        get() = javaResource.startIpAddress().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object MongoClusterFirewallRuleMapper : ResourceMapper<MongoClusterFirewallRule> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.documentdb.MongoClusterFirewallRule::class == javaResource::class

    override fun map(javaResource: Resource): MongoClusterFirewallRule =
        MongoClusterFirewallRule(
            javaResource as
                com.pulumi.azurenative.documentdb.MongoClusterFirewallRule,
        )
}

/**
 * @see [MongoClusterFirewallRule].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [MongoClusterFirewallRule].
 */
public suspend fun mongoClusterFirewallRule(
    name: String,
    block: suspend MongoClusterFirewallRuleResourceBuilder.() -> Unit,
): MongoClusterFirewallRule {
    val builder = MongoClusterFirewallRuleResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [MongoClusterFirewallRule].
 * @param name The _unique_ name of the resulting resource.
 */
public fun mongoClusterFirewallRule(name: String): MongoClusterFirewallRule {
    val builder = MongoClusterFirewallRuleResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/documentdb/kotlin/MongoClusterFirewallRule.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.documentdb.kotlin

import com.pulumi.azurenative.documentdb.kotlin.outputs.SystemDataResponse
import com.pulumi.azurenative.documentdb.kotlin.outputs.SystemDataResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit

/**
 * Builder for [MongoClusterFirewallRule].
 */
@PulumiTagMarker
public class MongoClusterFirewallRuleResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: MongoClusterFirewallRuleArgs = MongoClusterFirewallRuleArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend MongoClusterFirewallRuleArgsBuilder.() -> Unit) {
        val builder = MongoClusterFirewallRuleArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.CustomResourceOptions.opts(block)
    }

    internal fun build(): MongoClusterFirewallRule {
        val builtJavaResource =
            com.pulumi.azurenative.documentdb.MongoClusterFirewallRule(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return MongoClusterFirewallRule(builtJavaResource)
    }
}

/**
 * Represents a mongo cluster firewall rule.
 * Azure REST API version: 2023-03-15-preview.
 * Other available API versions: 2023-09-15-preview, 2023-11-15-preview, 2024-02-15-preview.
 * ## Example Usage
 * ### Create a firewall rule of the mongo cluster
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var mongoClusterFirewallRule = new AzureNative.DocumentDB.MongoClusterFirewallRule("mongoClusterFirewallRule", new()
 *     {
 *         EndIpAddress = "255.255.255.255",
 *         FirewallRuleName = "rule1",
 *         MongoClusterName = "myMongoCluster",
 *         ResourceGroupName = "TestGroup",
 *         StartIpAddress = "0.0.0.0",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/documentdb/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := documentdb.NewMongoClusterFirewallRule(ctx, "mongoClusterFirewallRule", &documentdb.MongoClusterFirewallRuleArgs{
 * 			EndIpAddress:      pulumi.String("255.255.255.255"),
 * 			FirewallRuleName:  pulumi.String("rule1"),
 * 			MongoClusterName:  pulumi.String("myMongoCluster"),
 * 			ResourceGroupName: pulumi.String("TestGroup"),
 * 			StartIpAddress:    pulumi.String("0.0.0.0"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.documentdb.MongoClusterFirewallRule;
 * import com.pulumi.azurenative.documentdb.MongoClusterFirewallRuleArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var mongoClusterFirewallRule = new MongoClusterFirewallRule("mongoClusterFirewallRule", MongoClusterFirewallRuleArgs.builder()
 *             .endIpAddress("255.255.255.255")
 *             .firewallRuleName("rule1")
 *             .mongoClusterName("myMongoCluster")
 *             .resourceGroupName("TestGroup")
 *             .startIpAddress("0.0.0.0")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:documentdb:MongoClusterFirewallRule rule1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.DocumentDB/mongoClusters/{mongoClusterName}/firewallRules/{firewallRuleName}
 * ```
 */
public class MongoClusterFirewallRule internal constructor(
    override val javaResource: com.pulumi.azurenative.documentdb.MongoClusterFirewallRule,
) : KotlinCustomResource(javaResource, MongoClusterFirewallRuleMapper) {
    /**
     * The end IP address of the mongo cluster firewall rule. Must be IPv4 format.
     */
    public val endIpAddress: Output<String>
        get() = javaResource.endIpAddress().applyValue({ args0 -> args0 })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * The provisioning state of the firewall rule.
     */
    public val provisioningState: Output<String>
        get() = javaResource.provisioningState().applyValue({ args0 -> args0 })

    /**
     * The start IP address of the mongo cluster firewall rule. Must be IPv4 format.
     */
    public val startIpAddress: Output<String>
        get() = javaResource.startIpAddress().applyValue({ args0 -> args0 })

    /**
     * Azure Resource Manager metadata containing createdBy and modifiedBy information.
     */
    public val systemData: Output<SystemDataResponse>
        get() = javaResource.systemData().applyValue({ args0 -> args0.let({ args0 -> toKotlin(args0) }) })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })
}

public object MongoClusterFirewallRuleMapper : ResourceMapper<MongoClusterFirewallRule> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.documentdb.MongoClusterFirewallRule::class == javaResource::class

    override fun map(javaResource: Resource): MongoClusterFirewallRule =
        MongoClusterFirewallRule(
            javaResource as
                com.pulumi.azurenative.documentdb.MongoClusterFirewallRule,
        )
}

/**
 * @see [MongoClusterFirewallRule].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [MongoClusterFirewallRule].
 */
public suspend fun mongoClusterFirewallRule(
    name: String,
    block: suspend MongoClusterFirewallRuleResourceBuilder.() -> Unit,
): MongoClusterFirewallRule {
    val builder = MongoClusterFirewallRuleResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [MongoClusterFirewallRule].
 * @param name The _unique_ name of the resulting resource.
 */
public fun mongoClusterFirewallRule(name: String): MongoClusterFirewallRule {
    val builder = MongoClusterFirewallRuleResourceBuilder()
    builder.name(name)
    return builder.build()
}
